#include "vfs/Doom3FileSystem.h"
#include "module/StaticModule.h"

namespace vfs
{

// Static module instance
module::StaticModuleRegistration<Doom3FileSystem> doom3FileSystemModule;

}
